linux-next: manual merge of the hwpoison tree with Linus' tree

From: Stephen Rothwell
Date: Wed Dec 16 2009 - 00:21:17 EST


Hi Andi,

Today's linux-next merge of the hwpoison tree got a conflict in
mm/memcontrol.c between commit 407f9c8b0889ced1dbe2f9157e4e60c61329d5c9
("ksm: mem cgroup charge swapin copy") from Linus' tree and commit
eacbcea706766709f5c3bbbca208c04558a8d72f ("memcg: rename and export
try_get_mem_cgroup_from_page()") from the hwpoison tree.

Just context changes. I fixed it up (see below) and can carry the fix
for a while.
--
Cheers,
Stephen Rothwell sfr@xxxxxxxxxxxxxxxx

diff --cc mm/memcontrol.c
index e0c2066,4e51af7..0000000
--- a/mm/memcontrol.c
+++ b/mm/memcontrol.c
@@@ -1737,13 -1739,12 +1739,13 @@@ int mem_cgroup_try_charge_swapin(struc
goto charge_cur_mm;
/*
* A racing thread's fault, or swapoff, may have already updated
* the pte, and even removed page from swap cache: return success
* to go on to do_swap_page()'s pte_same() test, which should fail.
*/
if (!PageSwapCache(page))
- return 0;
+ goto charge_cur_mm;
- mem = try_get_mem_cgroup_from_swapcache(page);
+ mem = try_get_mem_cgroup_from_page(page);
if (!mem)
goto charge_cur_mm;
*ptr = mem;
@@@ -1737,13 -1739,12 +1739,13 @@@ int mem_cgroup_try_charge_swapin(struc
/*
* A racing thread's fault, or swapoff, may have already updated
- * the pte, and even removed page from swap cache: return success
- * to go on to do_swap_page()'s pte_same() test, which should fail.
+ * the pte, and even removed page from swap cache: in those cases
+ * do_swap_page()'s pte_same() test will fail; but there's also a
+ * KSM case which does need to charge the page.
*/
if (!PageSwapCache(page))
--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at http://vger.kernel.org/majordomo-info.html
Please read the FAQ at http://www.tux.org/lkml/